package com.zd.exam.mapper;

import java.util.List;

import com.zd.exam.domain.ElUserBook;
import org.apache.ibatis.annotations.Param;

/**
 * 错题本Mapper接口
 *
 * @author zd
 * @date 2021-09-01
 */
public interface ElUserBookMapper {
    /**
     * 查询错题本
     *
     * @param id 错题本主键
     * @return 错题本
     */
    public ElUserBook selectElUserBookById(Long id);

    /**
     * 查询错题本列表
     *
     * @param elUserBook 错题本
     * @return 错题本集合
     */
    public List<ElUserBook> selectElUserBookList(ElUserBook elUserBook);

    /**
     * 新增错题本
     *
     * @param elUserBook 错题本
     * @return 结果
     */
    public int insertElUserBook(ElUserBook elUserBook);

    /**
     * 修改错题本
     *
     * @param elUserBook 错题本
     * @return 结果
     */
    public int updateElUserBook(ElUserBook elUserBook);

    /**
     * 删除错题本
     *
     * @param id 错题本主键
     * @return 结果
     */
    public int deleteElUserBookById(Long id);

    /**
     * 批量删除错题本
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteElUserBookByIds(Long[] ids);

    int selectMaxSort(@Param("examId") Long examId, @Param("userId") Long userId);
}
